@@ -50,7 +50,7 @@ pub fn verify_shred_cpu(packet: &Packet, slot_leaders: &HashMap<u64, [u8; 32]>)
     let slot_start = sig_end + size_of::<ShredType>();
     let slot_end = slot_start + size_of::<u64>();
     let msg_start = sig_end;
-    if packet.meta.discard {
+    if packet.meta.discard() {
         return Some(0);
     }
     trace!("slot start and end {} {}", slot_start, slot_end);
@@ -58,7 +58,7 @@ pub fn verify_shred_cpu(packet: &Packet, slot_leaders: &HashMap<u64, [u8; 32]>)
         return Some(0);
     }
     let slot: u64 = limited_deserialize(&packet.data[slot_start..slot_end]).ok()?;
-    let msg_end = if packet.meta.repair {
+    let msg_end = if packet.meta.repair() {
         packet.meta.size.saturating_sub(SIZE_OF_NONCE)
     } else {
         packet.meta.size
@@ -119,7 +119,7 @@ fn slot_key_data_for_gpu<
                     .map(|packet| {
                         let slot_start = size_of::<Signature>() + size_of::<ShredType>();
                         let slot_end = slot_start + size_of::<u64>();
-                        if packet.meta.size < slot_end || packet.meta.discard {
+                        if packet.meta.size < slot_end || packet.meta.discard() {
                             return std::u64::MAX;
                         }
                         let slot: Option<u64> =
@@ -204,7 +204,7 @@ fn shred_gpu_offsets(
             let sig_start = pubkeys_end;
             let sig_end = sig_start + size_of::<Signature>();
             let msg_start = sig_end;
-            let msg_end = if packet.meta.repair {
+            let msg_end = if packet.meta.repair() {
                 sig_start + packet.meta.size.saturating_sub(SIZE_OF_NONCE)
             } else {
                 sig_start + packet.meta.size
